@@ -2,11 +2,11 @@ bigssa <-
   function(formula,data=NULL,type=NULL,nknots=NULL,rparm=NA,
            lambdas=NULL,skip.iter=TRUE,se.fit=FALSE,rseed=1234,
            gcvopts=NULL,knotcheck=TRUE,gammas=NULL,weights=NULL,
-           random=NULL,remlalg=c("FS","EM","none"),remliter=500,
-           remltol=10^-4,remltau=NULL) {
+           random=NULL,remlalg=c("FS","NR","EM","none"),
+           remliter=500,remltol=10^-4,remltau=NULL) {
     ###### Fits Smoothing Spline ANOVA models
     ###### Nathaniel E. Helwig (helwig@umn.edu)
-    ###### Last modified: July 30, 2015
+    ###### Last modified: August 10, 2015
     
     if(class(data)[1]=="makessa"){
       ssafit <- ssawork(formula,data)
