@@ -21,17 +21,18 @@ imagebar <-
     oldplt <- par()$plt
     on.exit(par(plt=oldplt))
     if(drawbar){
-      # plot image 
-      par(plt=pltimage)
-      image(x,y,z,col=col,breaks=breaks,...)
       # plot color bar
-      par(plt=pltbar,new=TRUE)
+      par(plt=pltbar)
       plot(1,1,t="n",ylim=zlim,xlim=c(0,1),xaxt="n",yaxt="n",xaxs="i",yaxs="i",xlab="",ylab="")
-      axis(4,cex.axis=zcex.axis); mtext(zlab,side=4,line=zline,cex=zcex.lab*par()$cex)
+      axis(4,cex.axis=zcex.axis)
+      mtext(zlab,side=4,line=zline,cex=zcex.lab*par()$cex)
       for (ii in 1:ncolor) {
         idx <- zlim[1] + (ii-1)/scales
         rect(0,idx,1,(idx+1/scales),col=col[ii],border=NA)
       }
+      # plot image 
+      par(plt=pltimage,new=TRUE)
+      image(x,y,z,col=col,breaks=breaks,...)
     } else {
       # plot image
       par(plt=pltimage)
